
:autogenerated:

..
    This file is autogenerated by `sphinx-api`.

###################################
Sample usage for gluesemantics_malt
###################################

.. include:: ../../nltk/test/gluesemantics_malt.doctest